function [delta_phi]=model_electrode_loss_bvp4c(i_applied,params,E0)

% i>0: oxidation
% i<0: reduction

% c_ox=params(1);         % mol/m^3
% c_red=params(2);        % mol/m^3
% kappa_eff=params(3);    % S/m
% k_c=params(4);          % m/s
% k_m_ox=params(5);          % m/s
% a_e=params(6);          % m^-1
L_e=params(7);          % m
% F=params(8);            % C/mol
% R=params(9);            % J/mol/K
% T=params(10);           % K
% alpha_a=params(11);     % -
% k_a=params(12);         % m/s
% k_m_red=params(13);     % m/s

npts=50+1;

params2=[params;i_applied]; % parameters
diffunc2=@(x,y) diffunc(x,y,params2);                % diff eq func
bvpinguess2=@(x0) bvpinguess(x0,params2);            % initial guess function
f_bc2=@(y0,y1) f_bc(y0,y1,params2);                  % bc function

solinit = bvpinit(linspace(0,L_e,npts),bvpinguess2);    % initial guess
try 
    sol = bvp4c(diffunc2,f_bc2,solinit);                % call bvp solver
    
    ysol=sol.y;
    xsol=sol.x;
    xysol=[xsol;ysol];
    
%     delta_phi=xysol(2,1);   % V, overpotential at the membrane
    delta_phi=mean(xysol(2,:)); % V, average overpotential

catch
    delta_phi=sign(i_applied).*E0;    % V, arbitrary large overpotential
%     disp('bad point');
end

end

function dydxs=diffunc(~,delphi,params)
% returns y' given x and y
% note, integration from x_tilda is 0 (membrane) to 1 (graphite plate)
c_ox=params(1);         % mol/m^3
c_red=params(2);        % mol/m^3
kappa_eff=params(3);    % S/m
k_c=params(4);          % m/s
k_m_ox=params(5);          % m/s
a_e=params(6);          % m^-1
% L_e=params(7);          % m
F=params(8);            % C/mol
R=params(9);            % J/mol/K
T=params(10);           % K
alpha_a=params(11);     % -
k_a=params(12);         % m/s
k_m_red=params(13);     % m/s
% i_applied=params(14);       % A m^-2

detasdxs01=delphi(2);
% detasdxs02=(c_ox.*exp(-F.*delphi(1)./(R.*T))-c_red.*exp(F.*delphi(1)./(R.*T)))./...
%     (kappa_eff./(F.*a_e.*k_0)+kappa_eff./(F.*a_e.*k_m).*(exp(F.*delphi(1)./(R.*T))+exp(-F.*delphi(1)./(R.*T))));
detasdxs02=(c_red.*k_a.*F.*a_e.*exp(alpha_a.*F.*delphi(1)./(R.*T))-...
    c_ox.*k_c.*F.*a_e.*exp(-(1-alpha_a).*F.*delphi(1)./(R.*T)))./...
    (kappa_eff.*(1+k_a./k_m_red.*exp(alpha_a.*F.*delphi(1)./(R.*T))...
    +k_c./k_m_ox.*exp(-(1-alpha_a).*F.*delphi(1)./(R.*T))));


dydxs=[detasdxs01;detasdxs02]; 

end

function res = f_bc(y0,y1,params)
% boundary conditions

% c_ox=params(1);         % mol/m^3
% c_red=params(2);        % mol/m^3
kappa_eff=params(3);    % S/m
% k_0=params(4);          % m/s
% k_m=params(5);          % m/s
% a_e=params(6);          % m^-1
% L_e=params(7);          % m
% F=params(8);            % C/mol
% R=params(9);            % J/mol/K
% T=params(10);           % K
% alpha_a=params(11);     % -
% k_a=params(12);         % m/s
% k_m_red=params(13);     % m/s
i_applied=params(14);       % A m^-2

res01=y1(2);                % ionic current at current collector
res02=-kappa_eff.*y0(2)-i_applied;      % current at membrane 
res=[res01;res02];
end

function yi = bvpinguess(x,params)
% initial guess for solution



% c_ox=params(1);         % mol/m^3
% c_red=params(2);        % mol/m^3
kappa_eff=params(3);    % S/m
% k_0=params(4);          % m/s
% k_m=params(5);          % m/s
% a_e=params(6);          % m^-1
L_e=params(7);         % m
F=params(8);            % C/mol
R=params(9);            % J/mol/K
T=params(10);           % K
% alpha_a=params(11);     % -
% k_a=params(12);         % m/s
% k_m_red=params(13);     % m/s
i_applied=params(14);       % A m^-2

yi01=i_applied.*(L_e.*x-x.^2/2)./L_e./kappa_eff+sign(i_applied).*R*T./F;    
yi02=(i_applied.*(L_e-x)./L_e)./kappa_eff;      

yi=[yi01;yi02];

end